<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:fo="http://www.w3.org/1999/XSL/Format"
xmlns:rx="http://www.renderx.com/XSL/Extensions">

  <xsl:param name="start-indent-number">20</xsl:param>
  <xsl:param name="start-indent-unite">pt</xsl:param>
  <xsl:param name="distance-between-starts-number">25</xsl:param>
  <xsl:param name="distance-between-starts-unite">pt</xsl:param>
  <xsl:param name="ajout-indent-number">10</xsl:param>
  <xsl:param name="ajout-distance-between-starts-number">10</xsl:param>
    
  <xsl:param name="font-family">Helvetica</xsl:param>
  <xsl:param name="font-size">10pt</xsl:param>
  <xsl:param name="font-weight">normal</xsl:param>
  <xsl:param name="font-variant">normal</xsl:param>
  <xsl:param name="text-align">start</xsl:param>

  <xsl:variable name="CurrentLang" select="'FR'" />

  <!-- FIRST TEMPLATE -->
  <xsl:template match="/">
    <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format" word-spacing.minimum="0.17em">
      <xsl:for-each select="DMODULE">
        <xsl:apply-templates select="." />
      </xsl:for-each>
    </fo:root>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                         RULES FOR CONTENT                           * -->
  <!-- *********************************************************************** -->
  <xsl:template match="CONTENT">
    <xsl:apply-templates />
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                         RULES FOR DM933                             * -->
  <!-- *********************************************************************** -->
  <xsl:template match="DM933">
    <!-- actual layout -->
    <fo:page-sequence master-reference="PSM-dmodule" initial-page-number="1" >
      <!-- body -->
      <fo:flow flow-name="body-dmodule">
        <xsl:apply-templates select="IDSTATUS" />
        <fo:block id="bkDM933" break-before="page"/>
        <fo:block>
          <xsl:apply-templates />
        </fo:block>
      </fo:flow>
    </fo:page-sequence>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                         RULES FOR DMODULE                           * -->
  <!-- *********************************************************************** -->
  <xsl:template match="DMODULE">
    <!-- layout-master-set -->
    <xsl:call-template name="template-page">
    </xsl:call-template>
    <xsl:apply-templates />   

  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                        RULES FOR MAINFUNC                           * -->
  <!-- *********************************************************************** -->
  <xsl:template match="MAINFUNC">
    <fo:block>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                          RULES FOR NOTE                             * -->
  <!-- *********************************************************************** -->
  <xsl:template match="NOTE">
    <xsl:param name="start-indent-number" select="52" />
    <xsl:param name="distance-between-starts-number" select="20" />
    <xsl:variable name="mark" select="@MARK" />
    <xsl:if test="$mark='1'">
      <fo:change-bar-begin change-bar-width="1mm" change-bar-offset="6mm" change-bar-placement="left"
      change-bar-class="NOTE" change-bar-style="solid" />
    </xsl:if>
    <fo:block keep-with-previous="always">
      <xsl:choose>
        <xsl:when test="parent::ENTRY">
          <fo:block space-before.optimum="14pt" text-align="left">
            <fo:inline font-weight="bold">
              <xsl:text>Note</xsl:text>
            </fo:inline>
          </fo:block>
          <xsl:if test="PARA">
            <fo:block>
              <xsl:for-each select="PARA">
                <xsl:variable name="markT" select="@MARK" />
                <xsl:variable name="changeT" select="@CHANGE" />
                <!-- list start -->
                <fo:list-block provisional-distance-between-starts="{$distance-between-starts-number}{$distance-between-starts-unite}"
                               font-family="{$font-family}"
                               font-size="{$font-size}">
                  <!-- list item -->
                  <fo:list-item space-before.optimum="6pt">
                    <!-- insert a bullet -->
                    <fo:list-item-label end-indent="label-end()">
                    </fo:list-item-label>
                    <!-- list text -->
                    <fo:list-item-body start-indent="body-start()">
                      <fo:block>
                        <xsl:if test="name(.)='NOTE'">
                          <xsl:apply-templates select=".">
                            <xsl:with-param name="start-indent-number"
                                            select="$start-indent-number + $ajout-indent-number" />
                            <xsl:with-param name="distance-between-starts-number"
                                            select="$distance-between-starts-number + $ajout-distance-between-starts-number" />
                          </xsl:apply-templates>
                        </xsl:if>
                        <xsl:if test="name(.)!='NOTE'">
                          <xsl:apply-templates />
                        </xsl:if>
                      </fo:block>
                    </fo:list-item-body>
                  </fo:list-item>
                </fo:list-block>
              </xsl:for-each>
            </fo:block>
          </xsl:if>
          <xsl:if test="TABLE">
            <fo:block>
              <xsl:apply-templates select="TABLE" />
            </fo:block>
          </xsl:if>
          <xsl:if test="FIGURE">
            <fo:block>
              <xsl:apply-templates select="FIGURE" />
            </fo:block>
          </xsl:if>
          <xsl:if test="FOLDOUT">
            <fo:block>
              <xsl:apply-templates select="FOLDOUT" />
            </fo:block>
            <fo:block text-align="start">
              <xsl:apply-templates />
            </fo:block>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <fo:block space-before.optimum="14pt" keep-with-next="always">
            <fo:inline font-weight="bold">
              <xsl:text>Note</xsl:text>
              <xsl:if test="following-sibling::NOTE[1]|preceding-sibling::NOTE[1]">
                <xsl:number format=" 1" />
              </xsl:if>
            </fo:inline>
          </fo:block>
          <fo:block>
            <xsl:if test="PARA">
              <xsl:for-each select="PARA">
                <xsl:variable name="markU" select="@MARK" />
                <xsl:variable name="changeU" select="@CHANGE" />
                <!-- list start -->
                <fo:list-block provisional-distance-between-starts="{$distance-between-starts-number}{$distance-between-starts-unite}"
                               font-family="{$font-family}"
                               font-size="{$font-size}">
                  <!-- list item -->
                  <fo:list-item space-before.optimum="6pt">
                    <!-- insert a bullet -->
                    <fo:list-item-label end-indent="label-end()">
                    </fo:list-item-label>
                    <!-- list text -->
                    <fo:list-item-body start-indent="body-start()">
                      <fo:block>
                        <xsl:if test="name(.)='NOTE'">
                          <xsl:apply-templates select=".">
                            <xsl:with-param name="start-indent-number"
                                            select="$start-indent-number + $ajout-indent-number" />
                            <xsl:with-param name="distance-between-starts-number"
                                            select="$distance-between-starts-number + $ajout-distance-between-starts-number" />
                          </xsl:apply-templates>
                        </xsl:if>
                        <xsl:if test="name(.)!='NOTE'">
                          <xsl:apply-templates />
                        </xsl:if>
                      </fo:block>
                    </fo:list-item-body>
                  </fo:list-item>
                </fo:list-block>
              </xsl:for-each>
            </xsl:if>
            <xsl:if test="TABLE">
              <xsl:apply-templates select="TABLE" />
            </xsl:if>
            <xsl:if test="FIGURE">
              <xsl:apply-templates select="FIGURE" />
            </xsl:if>
            <xsl:if test="FOLDOUT">
              <xsl:apply-templates select="FOLDOUT" />
            </xsl:if>
            <xsl:if test="CAPTION">
              <xsl:apply-templates select="CAPTION" />
            </xsl:if>
          </fo:block>
        </xsl:otherwise>
      </xsl:choose>
    </fo:block>
    <xsl:if test="$mark='1'">
      <fo:change-bar-end change-bar-class="NOTE"/>
    </xsl:if>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                           RULES FOR PAGE                            * -->
  <!-- *********************************************************************** -->
  <xsl:template name="template-page">
    <fo:layout-master-set>
      <fo:simple-page-master master-name="dmodule_first"
        page-width="210mm"
        page-height="297mm"
        margin-top="8mm"
        margin-bottom="16mm"
        margin-left="25mm"
        margin-right="15mm">
            <fo:region-body region-name="body-dmodule"
              margin-top="24mm"
              margin-bottom="18mm" />
      </fo:simple-page-master>
      <fo:simple-page-master master-name="dmodule_rest"
        page-width="210mm"
        page-height="297mm"
        margin-top="8mm"
        margin-bottom="16mm"
        margin-left="25mm"
        margin-right="15mm">
            <fo:region-body region-name="body-dmodule"
              margin-top="22mm"
              margin-bottom="18mm" />
      </fo:simple-page-master>
      <fo:page-sequence-master master-name="PSM-dmodule">
        <fo:repeatable-page-master-alternatives>
          <fo:conditional-page-master-reference master-reference="dmodule_first"
            page-position="first" />
          <fo:conditional-page-master-reference master-reference="dmodule_rest"
            page-position="rest" />
        </fo:repeatable-page-master-alternatives>
      </fo:page-sequence-master>
    </fo:layout-master-set>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                          RULES FOR PARA                             * -->
  <!-- *********************************************************************** -->
  <xsl:template match="PARA">
    <xsl:variable name="id" select="@ID" />
    <xsl:variable name="mark" select="@MARK" />
    <xsl:if test="$mark='1'">
      <fo:change-bar-begin change-bar-width="1mm" change-bar-offset="6mm" change-bar-placement="left"
      change-bar-class="PARA" change-bar-style="solid" />
    </xsl:if>
    <xsl:if test="(preceding-sibling::PARA[1]) and (parent::STEP1|parent::STEP2|parent::STEP3|parent::STEP4|parent::STEP5)">
      <fo:block space-after.optimum="14pt" />
    </xsl:if>
        <xsl:choose>
              <!-- EWA j'ai enlevé le text-align="left"-->
              <xsl:when test="parent::CAUTION|parent::WARNING">
                <fo:block font-weight="bold" >
                  <xsl:apply-templates />
                </fo:block>
              </xsl:when>
              <xsl:when test="parent::STEP1|parent::STEP2|parent::STEP3|parent::STEP4|parent::STEP5">
                <xsl:apply-templates />
                  <xsl:if test="child::EMPHASIS and not(preceding-sibling::PARA[1])">
                      <fo:block keep-with-next="always"/>
                  </xsl:if>
              </xsl:when>
              <xsl:when test="parent::SPECPARA">
                <xsl:apply-templates />
                  <xsl:if test="child::EMPHASIS and not(preceding-sibling::SPECPARA[1])">
                      <fo:block keep-with-next="always"/>
                  </xsl:if>
              </xsl:when>
              <xsl:otherwise>
                <fo:block>
                  <!-- Table footnotes  -->
                  <xsl:choose>
                    <xsl:when test="starts-with($id,'TN')">
                      <xsl:value-of select="number(substring-after($id,'-'))" />.
                      &#160;
                    </xsl:when>
                    <xsl:otherwise />
                  </xsl:choose>
                  <!-- /Table footnotes -->
                  <xsl:apply-templates />
                </fo:block>
              </xsl:otherwise>
        </xsl:choose>
    <xsl:if test="$mark='1'">
      <fo:change-bar-end change-bar-class="PARA"/>
    </xsl:if>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                        RULES FOR SPECPARA                           * -->
  <!-- *********************************************************************** -->
  <xsl:template match="SPECPARA">
    <xsl:variable name="mark" select="@MARK" />
    <fo:block>
      <xsl:if test="$mark='1'">
        <fo:change-bar-begin change-bar-width="1mm" change-bar-offset="6mm" change-bar-placement="left"
        change-bar-class="SPECPARA" change-bar-style="solid" />
      </xsl:if>
          <xsl:apply-templates />
      <xsl:if test="$mark='1'">
        <fo:change-bar-end change-bar-class="SPECPARA"/>
      </xsl:if>
    </fo:block>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                          RULES FOR STEP1                            * -->
  <!-- *********************************************************************** -->
  <xsl:template match="STEP1">
    <xsl:for-each select=".">
      <xsl:variable name="mark" select="@MARK" />
      <xsl:if test="$mark='1'">
        <fo:change-bar-begin change-bar-width="1mm" change-bar-offset="6mm" change-bar-placement="left"
        change-bar-class="STEP1" change-bar-style="solid" />
      </xsl:if>
          <!-- list start -->
          <fo:list-block start-indent="{$start-indent-number}{$start-indent-unite}"
                         provisional-distance-between-starts="{$distance-between-starts-number}{$distance-between-starts-unite}"
                         font-family="{$font-family}"
                         font-size="{$font-size}"
                         font-weight="{$font-weight}">
            <!-- list item -->
            <fo:list-item space-before.optimum="14pt">
              <!-- insert a bullet -->
              <fo:list-item-label end-indent="label-end()">
                <fo:block font-family="{$font-family}"
                         font-size="{$font-size}"
                         font-weight="{$font-weight}">
                  <xsl:number count="STEP1" level="single"
                  format="1" />
                </fo:block>
              </fo:list-item-label>
              <!-- list text -->
              <fo:list-item-body start-indent="body-start()">
                <fo:block font-size="{$font-size}"
                font-family="{$font-family}"
                font-weight="{$font-weight}"
                font-variant="{$font-variant}"
                text-align="{$text-align}">
                  <xsl:apply-templates select="SPECPARA|PARA" />
                  <xsl:apply-templates select="TABLE|FOLDOUT" />
                  <xsl:apply-templates select="STEP2">
                    <xsl:with-param name="start-indent-number"
                    select="$start-indent-number + $ajout-indent-number" />
                    <xsl:with-param name="distance-between-starts-number"
                                    select="$distance-between-starts-number + $ajout-distance-between-starts-number" />
                  </xsl:apply-templates>
                  <xsl:apply-templates select="FIGURE" />
                </fo:block>
              </fo:list-item-body>
            </fo:list-item>
          </fo:list-block>
          <!-- end list -->
      <xsl:if test="$mark='1'">
        <fo:change-bar-end change-bar-class="STEP1"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  <!-- *********************************************************************** -->
  <!-- *                          RULES FOR STEP2                            * -->
  <!-- *********************************************************************** -->
  <xsl:template match="STEP2">
    <xsl:param name="start-indent-number" select="." />
    <xsl:param name="distance-between-starts-number" select="." />
    <xsl:for-each select=".">
      <xsl:variable name="mark" select="@MARK" />
      <xsl:if test="$mark='1'">
        <fo:change-bar-begin change-bar-width="1mm" change-bar-offset="6mm" change-bar-placement="left"
        change-bar-class="STEP2" change-bar-style="solid" />
      </xsl:if>
    <fo:block >
          <!-- list start -->
          <fo:list-block start-indent="{$start-indent-number}{$start-indent-unite}"
                         provisional-distance-between-starts="{$distance-between-starts-number}{$distance-between-starts-unite}"
                         font-family="{$font-family}"
                         font-size="{$font-size}"
                         font-weight="{$font-weight}">
            <!-- list item -->
            <fo:list-item space-before.optimum="14pt">
              <!-- insert a bullet -->
              <fo:list-item-label end-indent="label-end()">
                <fo:block font-family="{$font-family}"
                         font-size="{$font-size}"
                         font-weight="{$font-weight}">
                  <xsl:number count="STEP1|STEP2" level="multiple"
                  format="1.1" />
                </fo:block>
              </fo:list-item-label>
              <!-- list text -->
              <fo:list-item-body start-indent="body-start()">
                <fo:block font-size="{$font-size}"
                font-family="{$font-family}"
                font-weight="{$font-weight}"
                font-variant="{$font-variant}"
                text-align="{$text-align}">
                  <xsl:apply-templates select="SPECPARA|PARA" />
                  <xsl:apply-templates select="TABLE|FOLDOUT" />
                  <xsl:apply-templates select="STEP3">
                    <xsl:with-param name="start-indent-number"
                    select="$start-indent-number + $ajout-indent-number" />
                    <xsl:with-param name="distance-between-starts-number"
                                    select="$distance-between-starts-number + $ajout-distance-between-starts-number" />
                  </xsl:apply-templates>
                  <xsl:apply-templates select="FIGURE" />
                </fo:block>
              </fo:list-item-body>
            </fo:list-item>
          </fo:list-block>
          <!-- end list -->
      </fo:block>
      <xsl:if test="$mark='1'">
        <fo:change-bar-end change-bar-class="STEP2"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>
